@@ -219,6 +219,7 @@ subset_nhdplus <- function(comids = NULL, output_file = NULL, nhdplus_data = NUL
 
   if (nhdplus_data == "download") {
 
+    tryCatch({
     for (layer_name in intersection_names) {
       if(is.null(out_list[layer_name][[1]])) {
         layer <- sf::st_transform(envelope, 4326) %>%
@@ -240,6 +241,10 @@ subset_nhdplus <- function(comids = NULL, output_file = NULL, nhdplus_data = NUL
         }
       }
     }
+    }, error = function(e) {
+      warning(e)
+      return(NULL)
+    })
 
   } else {
     if(!flowline_only) {
@@ -446,6 +451,10 @@ get_flowline_subset <- function(nhdplus_data, comids, output_file,
 
     fline <- get_nhdplus_byid(comids, tolower(layer_name))
 
+    if(is.null(fline)) {
+      return(NULL)
+    }
+
   } else {
 
     if(!layer_name %in% st_layers(nhdplus_data)$name) {
@@ -532,6 +541,10 @@ get_catchment_subset <- function(nhdplus_data, comids, output_file,
 
     catchment <- get_nhdplus_byid(comids, tolower(layer_name))
 
+    if(is.null(catchment)) {
+      return(NULL)
+    }
+
   } else {
 
     catchment <- get_nhd_data(nhdplus_data,layer_name, comids, "FEATUREID", status)
@@ -551,7 +564,7 @@ get_catchment_subset <- function(nhdplus_data, comids, output_file,
 }
 
 clean_bbox <- function(x) {
-  if("bbox" %in% names(x) && class(x$bbox[1]) == "list") {
+  if("bbox" %in% names(x) && inherits(x$bbox[1], "list")) {
     x$bbox <- sapply(x$bbox, paste, collapse = ",")
   }
 
@@ -827,9 +840,13 @@ subset_rpu <- function(fline, rpu, run_make_standalone = TRUE, strict = FALSE) {
     # find flowlines completely outside the RPU
     fline_sub_out <- filter(drop_geometry(fline), !.data$rpuid %in% rpu)
 
-    # join to the paths within the RPU
-    fline_sub_out <- left_join(fline_sub_out,
-                               ungroup(fline_sub_in),
+    # Need all paths in the domain outside the RPU and their tributary relations
+    # used just below. This filter avoids flowlines along the same levelpath.
+    lp_with_trib <-  filter(select(fline_sub_out, .data$levelpathi, .data$dnlevelpat),
+                            .data$levelpathi != .data$dnlevelpat)
+
+    # join to the paths within the RPU so we have the lp_top to filter on.
+    fline_sub_out <- left_join(fline_sub_out, ungroup(fline_sub_in),
                                by = "levelpathi")
 
     # filter so we have the stuff that is complete upstream of the rpu
@@ -837,13 +854,15 @@ subset_rpu <- function(fline, rpu, run_make_standalone = TRUE, strict = FALSE) {
                             .data$hydroseq > .data$lp_top)
 
     # want to keep anything left that does not have anything flowing to it.
+    # to do this, we need fline_sub_out to include things we CAN remove later.
+
     # first select only levelpath and dnlevelpat and get rid of cruft
     fline_sub_out <- distinct(select(ungroup(fline_sub_out),
                                      .data$levelpathi, .data$dnlevelpat))
-    # get rid of the ones along the same path -- dnlevelpaths that are left
-    # can be removed
-    fline_sub_out <- filter(fline_sub_out,
-                            .data$dnlevelpat != .data$levelpathi)
+
+    # levelpaths with tributaries that are outside the domain.
+    lp_with_trib <- filter(lp_with_trib, .data$dnlevelpat %in% fline_sub_out$levelpathi)
+    fline_sub_out <- filter(fline_sub_out, .data$levelpathi %in% lp_with_trib$dnlevelpat)
   }
 
 
@@ -852,6 +871,7 @@ subset_rpu <- function(fline, rpu, run_make_standalone = TRUE, strict = FALSE) {
   # of trusting the rpuid to be useable.
   fline <- left_join(fline, fline_sub_in, by = "levelpathi")
 
+  # first filter to levelpaths included in our domain.
   fline <- group_by(filter(fline, .data$levelpathi %in% fline_sub_in$levelpathi),
                     .data$levelpathi)
 
@@ -863,11 +883,17 @@ subset_rpu <- function(fline, rpu, run_make_standalone = TRUE, strict = FALSE) {
                       .data$hydroseq <= .data$lp_top)
 
   } else if(!nrow(fline_sub_out) == 0) {
-    # if nothing is left in fline_sub_out, we are fine and can move on.
+
+    # fline_sub_out contains levelpaths that we can subject to the lp_top / lp_bot
+    # filter. All other levelpaths should be left whole.
+
     fline <- filter(fline,
-                    .data$levelpathi %in% fline_sub_in$levelpathi &
+                    # for levelpaths in flinesub out, filter hydrosequence
+                    (.data$levelpathi %in% fline_sub_out$levelpathi &
                       (.data$hydroseq >= .data$lp_bot &
-                         .data$hydroseq <= .data$lp_top))
+                         .data$hydroseq <= .data$lp_top)) |
+                      # keep everything not in fline_sub_out
+                      !.data$levelpathi %in% fline_sub_out$levelpathi)
 
   }
 
@@ -918,12 +944,19 @@ get_nhdplus_bybox <- function(box, layer, streamorder = NULL) {
 
   if(!layer %in% c("nhdarea", "nhdwaterbody", "nhdflowline_network",
                    "nhdflowline_nonnetwork", "catchmentsp")) {
-    stop("Layer must be one of nhdarea, nhdwaterbody")
+    stop("Layer must be one of nhdarea, nhdwaterbody, nhdflowline_network, nhdflowline_nonnetwork, catchmentsp.")
   }
 
   type <- dplyr::filter(query_usgs_geoserver(),
                         .data$geoserver == layer)$user_call
 
-  query_usgs_geoserver(AOI = box,
-                       type = type)
+
+  if(layer == "nhdflowline_network") {
+    query_usgs_geoserver(AOI = box,
+                         type = type,
+                         filter = streamorder_filter(streamorder))
+  } else {
+    query_usgs_geoserver(AOI = box,
+                         type = type)
+  }
 }
